package main

import (
	"git.javil.eu/jacob1123/budgeteer/bcrypt"
	"git.javil.eu/jacob1123/budgeteer/config"
	"git.javil.eu/jacob1123/budgeteer/http"
	"git.javil.eu/jacob1123/budgeteer/jwt"
	"git.javil.eu/jacob1123/budgeteer/postgres"
)

func main() {
	cfg, err := config.LoadConfig()
	if err != nil {
		panic("Could not load Config")
	}

	bv := &bcrypt.Verifier{}

	db, err := postgres.Connect(cfg.DatabaseHost, cfg.DatabaseUser, cfg.DatabasePassword, cfg.DatabaseName)
	if err != nil {
		panic("Failed connecting to DB")
	}

	us, err := postgres.NewRepository(db)
	if err != nil {
		panic("Failed building Repository")
	}

	tv := &jwt.TokenVerifier{}

	h := &http.Handler{
		Service:             us,
		TokenVerifier:       tv,
		CredentialsVerifier: bv,
	}
	h.Serve()
}
